// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.




#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include "pieview.h"
#include "indexer.h"
#include <QtGui>


namespace Ui {
    class MainWindow;
}



class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit MainWindow(QWidget *parent = 0);


    void save(QDataStream &out, Folder folder);
    Folder load(QDataStream &in);

    ~MainWindow();
public slots:
    void save();
    void createIndex();
    void load();

    void clickedOnPie(QModelIndex index);
    void doubleClickedOnPie(QModelIndex index);
    void makePie(QString id);
    void stepUpDir();
    void openFileFolder();
    void indexingFinished();
    void updateIndexingStatus();
    void refreshChart();


protected:
    void changeEvent(QEvent *e);

private:
    void setupModel();
    void setupViews();

    QAbstractItemModel *model;
    QAbstractItemView *pieChart;
    QItemSelectionModel *selectionModel;
    QString fldId;
    Indexer *indexer;

    QTimer indexStatusUpdateTimer;

    Ui::MainWindow *ui;
};

#endif // MAINWINDOW_H
